pynetworks
======================================

.. include:: README.rst

.. toctree::
    :caption: Quick Start
    :maxdepth: 2
    :hidden:

    README

.. toctree::
    :caption: Full Documentation
    :maxdepth: 2
    :hidden:

    documentation